@@ -5,14 +5,13 @@
 # Created: 05.05.2017
 # Copyright (C) 2017, Manfred Moitzi
 # License: MIT License
-from __future__ import unicode_literals
-
 try:
     import svgwrite
 except ImportError:
     # if svgwrite is not 'installed' append parent dir of __file__ to sys.path
-    import sys, os
-    sys.path.insert(0, os.path.abspath(os.path.split(os.path.abspath(__file__))[0]+'/..'))
+    import sys
+    from pathlib import Path
+    sys.path.insert(0, str(Path(__file__).resolve().parent.parent))
 
 import svgwrite
 
