@@ -11,7 +11,7 @@ import re
 from svgwrite.data import pattern
 from svgwrite.data.colors import colornames
 from svgwrite.data.svgparser import is_valid_transferlist, is_valid_pathdata, is_valid_animation_timing
-from svgwrite.utils import is_string, to_unicode
+from svgwrite.utils import is_string
 
 def iterflatlist(values):
     """ Flatten nested *values*, returns an *iterator*. """
@@ -76,7 +76,7 @@ class Full11TypeChecker(object):
         return value.strip() in colornames
 
     def is_frequency(self, value):
-        #frequency ::= number (~"Hz" | ~"kHz")
+        # frequency ::= number (~"Hz" | ~"kHz")
         if self.is_number(value):
             return True
         elif is_string(value):
@@ -84,14 +84,14 @@ class Full11TypeChecker(object):
         return False
 
     def is_FuncIRI(self, value):
-        #FuncIRI ::= "url(" <IRI> ")"
+        # FuncIRI ::= "url(" <IRI> ")"
         res = FUNCIRI_PATTERN.match(str(value).strip())
         if res:
             return self.is_IRI(res.group(1))
         return False
 
     def is_icccolor(self, value):
-        #icccolor ::= "icc-color(" name (comma-wsp number)+ ")"
+        # icccolor ::= "icc-color(" name (comma-wsp number)+ ")"
         res = ICCCOLOR_PATTERN.match(str(value).strip())
         if res:
             return self.is_list_of_T(res.group(1), 'name')
@@ -117,7 +117,7 @@ class Full11TypeChecker(object):
             return False
 
     def is_length(self, value):
-        #length ::= number ("em" | "ex" | "px" | "in" | "cm" | "mm" | "pt" | "pc" | "%")?
+        # length ::= number ("em" | "ex" | "px" | "in" | "cm" | "mm" | "pt" | "pc" | "%")?
         if value is None:
             return False
         if isinstance(value, (int, float)):
@@ -171,10 +171,10 @@ class Full11TypeChecker(object):
         #               | value comma-wsp list-of-values
         #comma-wsp  ::= (wsp+ ";" wsp*) | ("," wsp*)
         #wsp        ::= (#x20 | #x9 | #xD | #xA)
-        return self.is_list_of_T(value.replace(';', ' '), 'number')
+        return self.is_list_of_T(value.replace(';', ' '), 'string')
 
     def is_name(self, value):
-        #name  ::= [^,()#x20#x9#xD#xA] /* any char except ",", "(", ")" or wsp */
+        # name  ::= [^,()#x20#x9#xD#xA] /* any char except ",", "(", ")" or wsp */
         chars = frozenset(str(value).strip())
         if not chars or INVALID_NAME_CHARS.intersection(chars):
             return False
@@ -192,7 +192,7 @@ class Full11TypeChecker(object):
         #number-optional-number ::= number
         #                           | number comma-wsp number
         if is_string(value):
-            values = re.split(' *,? *', value.strip())
+            values = re.split('[ ,]+', value.strip())
             if 0 < len(values) < 3: # 1 or 2 numbers
                 for v in values:
                     if not self.is_number(v):
@@ -271,9 +271,8 @@ class Full11TypeChecker(object):
         # Nmtoken
         return bool(NMTOKEN_PATTERN.match(str(value).strip()))
 
-
     def is_shape(self, value):
-        #shape ::= (<top> <right> <bottom> <left>)
+        # shape ::= (<top> <right> <bottom> <left>)
         # where <top>, <bottom> <right>, and <left> specify offsets from the
         # respective sides of the box.
         # <top>, <right>, <bottom>, and <left> are <length> values
@@ -295,6 +294,12 @@ class Full11TypeChecker(object):
         else:
             return False
 
+    def is_list_of_text_decoration_style(self, value):
+        return self.is_list_of_T(value, t='text_decoration_style')
+
+    def is_text_decoration_style(self, value):
+        return value in ('overline', 'underline', 'line-through', 'blink')
+
     def get_func_by_name(self, funcname):
         return getattr(self,
                        'is_'+funcname.replace('-', '_'),
@@ -306,6 +311,7 @@ class Full11TypeChecker(object):
             return self.is_list_of_T(value, t)
         return self.get_func_by_name(typename)(value)
 
+
 FOCUS_CONST = frozenset(['nav-next', 'nav-prev', 'nav-up', 'nav-down', 'nav-left',
                          'nav-right', 'nav-up-left', 'nav-up-right', 'nav-down-left',
                          'nav-down-right'])
